@@ -7,7 +7,7 @@
     legend.mar = ifelse(horizontal, 3.1, 5.1), legend.lab = NULL, 
     graphics.reset = FALSE, bigplot = NULL, smallplot = NULL, 
     legend.only = FALSE, col = tim.colors(nlevel), lab.breaks = NULL, 
-    axis.args = NULL, legend.args = NULL, midpoint = FALSE, border=NA, lwd=1.0) {
+    axis.args = NULL, legend.args = NULL, midpoint = FALSE, border=NA, lwd.poly=1.0) {
     # Thanks to S. Koehler and  S. Woodhead
     # for comments on making this a better function
     #
@@ -48,7 +48,7 @@
         }
         else {
             poly.image(..., add = add, col = col, midpoint = midpoint,
-                            border=border, lwd=lwd)
+                            border=border, lwd.poly=lwd.poly)
         }
         big.par <- par(no.readonly = TRUE)
     }
